# Robot Framework - ConfluentKafkaLibrary

ConfluentKafkaLibrary library is wrapper for [confluent-kafka-python](https://github.com/confluentinc/confluent-kafka-python).

ConfluentKafkaLibrary works with latest confluent-kafka-python, tags are 1:1 (ConfluentKafkaLibrary 1.3.0 == confluent-kafka-python 1.3.0 ). Bugfixes and updates are set after the '-' e.g. `1.3.0-1`.

## Documentation

Keyword documentation is available [here](https://robooo.github.io/robotframework-ConfluentKafkaLibrary/)

How to generate documentation:

```
python -m robot.libdoc -f html src/ConfluentKafkaLibrary docs/index.html
```

## Installation

```
pip install robotframework-confluentkafkalibrary
```

## Usage Examples

See https://robooo.github.io/robotframework-ConfluentKafkaLibrary/#Examples

